@@ -327,8 +327,6 @@ const char stress_config[] =
 "#define HAVE_Decimal128\n"
 "#define HAVE_Decimal32\n"
 "#define HAVE_Decimal64\n"
-"#define HAVE_EGL_EXT_H\n"
-"#define HAVE_EGL_H\n"
 "#define HAVE_EIGEN\n"
 "#define HAVE_ENDMNTENT\n"
 "#define HAVE_ENDPWENT\n"
@@ -385,7 +383,6 @@ const char stress_config[] =
 "#define HAVE_Float32x\n"
 "#define HAVE_Float64\n"
 "#define HAVE_Float64x\n"
-"#define HAVE_GBM_H\n"
 "#define HAVE_GETAUXVAL\n"
 "#define HAVE_GETCPU\n"
 "#define HAVE_GETDOMAINNAME\n"
@@ -411,7 +408,6 @@ const char stress_config[] =
 "#define HAVE_GETTID\n"
 "#define HAVE_GETTIMEOFDAY\n"
 "#define HAVE_GETXATTR\n"
-"#define HAVE_GLES2_H\n"
 "#define HAVE_GMP_H\n"
 "#define HAVE_GRP_H\n"
 "#define HAVE_HSEARCH\n"
@@ -477,9 +473,6 @@ const char stress_config[] =
 "#define HAVE_LIB_BSD\n"
 "#define HAVE_LIB_CRYPT\n"
 "#define HAVE_LIB_DL\n"
-"#define HAVE_LIB_EGL\n"
-"#define HAVE_LIB_GBM\n"
-"#define HAVE_LIB_GLES2\n"
 "#define HAVE_LIB_GMP\n"
 "#define HAVE_LIB_JPEG\n"
 "#define HAVE_LIB_JUDY\n"
@@ -1067,6 +1060,8 @@ const char stress_config[] =
 "/* #define HAVE_BUILTIN_ROTATERIGHT8 */\n"
 "/* #define HAVE_CACHEFLUSH */\n"
 "/* #define HAVE_DELETE_MODULE */\n"
+"/* #define HAVE_EGL_EXT_H */\n"
+"/* #define HAVE_EGL_H */\n"
 "/* #define HAVE_FACCESSAT2 */\n"
 "/* #define HAVE_FCHMODAT2 */\n"
 "/* #define HAVE_FINIT_MODULE */\n"
@@ -1074,12 +1069,17 @@ const char stress_config[] =
 "/* #define HAVE_Float16x */\n"
 "/* #define HAVE_Float80 */\n"
 "/* #define HAVE_Float80x */\n"
+"/* #define HAVE_GBM_H */\n"
 "/* #define HAVE_GETEXECNAME */\n"
 "/* #define HAVE_GETMNTINFO */\n"
 "/* #define HAVE_GETXATTRAT */\n"
+"/* #define HAVE_GLES2_H */\n"
 "/* #define HAVE_HEAPSORT */\n"
 "/* #define HAVE_INIT_MB_MGR_AVX */\n"
 "/* #define HAVE_INTEL_IPSEC_MB_H */\n"
+"/* #define HAVE_LIB_EGL */\n"
+"/* #define HAVE_LIB_GBM */\n"
+"/* #define HAVE_LIB_GLES2 */\n"
 "/* #define HAVE_LIB_IPSEC_MB */\n"
 "/* #define HAVE_LISTXATTRAT */\n"
 "/* #define HAVE_LSM_GET_SELF_ATTR */\n"
